from pathlib import Path

import typer

from filess.orgnize import gather_file, search_prefixes
from filess.json_process import load_json

app = typer.Typer()


@app.command('run')
def run_command(target_path: str, sauce_path: str):
    """ソースディレクトリからターゲットディレクトリの名前を接頭語として持つファイル・ディレクトリを集める

    Args:
        target_path: ターゲットディレクトリのパス
        sauce_path: ソースディレクトリのパス

    Returns:
        void
    """
    outputs = gather_file(target_path, sauce_path)
    if outputs:
        [typer.echo(output) for output in outputs]


@app.command('json')
def json_command(json_path: str):
    """JSONファイルを読み込み、ファイル・ディレクトリを集める

    JSONファイルにはtargetとsaucesプロパティがあり、targetディレクトリの子ディレクトリ名を接頭語として、
    ソースディレクトリを探索し、接頭語を持つファイルをtargetディレクトリの子要素のディレクトリに集める。

    Args:
        json_path: JSONファイルのパス

    Returns:
        void
    """
    outputs = []
    config = load_json(json_path)
    target = Path(config['target'])
    sauces = list(map(lambda x: Path(x), config['sauces']))

    prefixes = search_prefixes(target)

    for prefix in prefixes:
        for sauce in sauces:
            target_child = target / prefix
            outputs += gather_file(target_child, sauce)

    if outputs:
        [typer.echo(output) for output in outputs]


def cli():
    app()
