from pathlib import Path

import typer


def search_prefixes(target_path: Path):
    """ターゲットディレクトリからプリフィックスを取得し、リストにして返す

    Args:
        target_path (Path): ターゲットディレクトリのパス

    Returns:
        list: プリフィックスのリスト
    """
    return [x.name for x in target_path.iterdir() if x.is_dir() if not x.name.startswith('.')]


def move_file(target: Path, file: Path):
    """ターゲットディレクトリにソースファイルもしくはソースディレクトリを移動させる。

    Args:
        target (Path):
        file (Path):

    Returns:
        str: 'Move to {移動先} from {移動元}'の形式で結果を返す
    """
    destination_path = target / file.name
    file.replace(destination_path)
    return f'Move to {destination_path} from {file}'


def gather_file(target_path: str, sauce_path: str):
    """1つのソースティレクトリからターゲットディレクトリへファイルを移動させ、整理する
    ソースティレクトリからターゲットディレクトリへファイルを移動させ、整理する

    Args:
        target_path (str): 文字列型のターゲットディレクトリのパス
        sauce_path (str): 文字列型のソースディレクトリのパス

    Returns:
        string[]: どのファイルをどこに移動させたかの文字列のリスト
    """
    target = Path(target_path)
    sauce = Path(sauce_path)
    results = []

    if not target.is_dir():
        typer.echo('ターゲットのパスはディレクトリへのパスを指定してください', err=True)
        return results
    elif not sauce.is_dir():
        typer.echo('ソースのパスはディレクトリへのパスを指定してください', err=True)
        return results

    prefix = target.name
    for child in sauce.iterdir():
        if child.name[:len(prefix)] == prefix:
            results.append(move_file(target, child))
    return results
